@@ -1,6 +1,8 @@
-# $Id: cmake-1.0.tcl 66929 2010-04-26 04:42:44Z jmr@macports.org $
-
+# -*- coding: utf-8; mode: tcl; c-basic-offset: 4; indent-tabs-mode: nil; tab-width: 4; truncate-lines: t -*- vim:fenc=utf-8:et:sw=4:ts=4:sts=4
+# $Id: cmake-1.0.tcl 104472 2013-03-26 02:37:15Z ryandesign@macports.org $
+#
 # Copyright (c) 2009 Orville Bennett <illogical1 at gmail.com>
+# Copyright (c) 2010-2013 The MacPorts Project
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -15,7 +17,7 @@
 # 3. Neither the name of Apple Computer, Inc. nor the names of its
 #    contributors may be used to endorse or promote products derived from
 #    this software without specific prior written permission.
-# 
+#
 # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 # "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 # LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
@@ -32,13 +34,15 @@
 # Usage:
 # PortGroup     cmake 1.0
 
+# standard place to install extra CMake modules
+set cmake_share_module_dir ${prefix}/share/cmake/modules
 
-depends_build       port:cmake
+depends_build-append port:cmake
 
 #FIXME: ccache works with cmake on linux
 configure.ccache    no
 
-configure.cmd       cmake
+configure.cmd       ${prefix}/bin/cmake
 
 configure.pre_args  -DCMAKE_INSTALL_PREFIX=${prefix}
 
@@ -47,25 +51,45 @@ configure.args      -DCMAKE_VERBOSE_MAKEFILE=ON \
                     -DCMAKE_BUILD_TYPE=Release \
                     -DCMAKE_BUILD_WITH_INSTALL_RPATH=ON \
                     -DCMAKE_INSTALL_NAME_DIR=${prefix}/lib \
-                    -DCMAKE_SYSTEM_PREFIX_PATH=\"${prefix}\;/usr\" \
-                    -DQT_QMAKE_EXECUTABLE=${prefix}/libexec/qt4-mac/bin/qmake \
+                    -DCMAKE_SYSTEM_PREFIX_PATH="${prefix}\;/usr" \
+                    -DCMAKE_MODULE_PATH=${cmake_share_module_dir} \
+                    -DCMAKE_FIND_FRAMEWORK=LAST \
                     -Wno-dev
-pre-configure {
-    if {${os.platform} == "darwin" && (![variant_isset universal] || ![variant_exists universal])} {
-        configure.args-append \
-            -DCMAKE_OSX_ARCHITECTURES=\"${configure.build_arch}\"
+
+platform darwin {
+    pre-configure {
+        if {[variant_exists universal] && [variant_isset universal]} {
+            if {[info exists universal_archs_supported]} {
+                global merger_configure_args
+                foreach arch ${universal_archs_to_use} {
+                    lappend merger_configure_args(${arch}) -DCMAKE_OSX_ARCHITECTURES=${arch}
+                }
+            } else {
+                configure.universal_args-append \
+                    -DCMAKE_OSX_ARCHITECTURES="[join ${configure.universal_archs} \;]"
+            }
+        } else {
+            configure.args-append \
+                -DCMAKE_OSX_ARCHITECTURES="${configure.build_arch}"
+        }
+        if {${configure.sdkroot} != ""} {
+            configure.args-append -DCMAKE_OSX_SYSROOT="${configure.sdkroot}"
+        } else {
+            # Witout this, cmake will choose an SDK and deployment target on its own.
+            configure.args-append -DCMAKE_OSX_SYSROOT=/ -DCMAKE_OSX_DEPLOYMENT_TARGET=""
+        }
     }
-    configure.universal_args-append \
-        -DCMAKE_OSX_ARCHITECTURES=\"[strsed ${configure.universal_archs} "g| |;|"]\"
 }
+
 configure.universal_args-delete --disable-dependency-tracking
-if {[info exists configure.sdkroot] && ${configure.sdkroot} != ""} {
-    configure.args-append -DCMAKE_OSX_SYSROOT="${configure.sdkroot}"
-} elseif {${os.arch} == "powerpc" && ${os.major} == "8"} {
-    configure.universal_args-append -DCMAKE_OSX_SYSROOT="${developer_dir}/SDKs/MacOSX10.4u.sdk"
-}
 
 variant debug description "Enable debug binaries" {
     configure.args-delete   -DCMAKE_BUILD_TYPE=Release
     configure.args-append   -DCMAKE_BUILD_TYPE=debugFull
 }
+
+# cmake doesn't like --enable-debug, so in case a portfile sets
+# --enable-debug (regardless of variant) we remove it
+if {[string first "--enable-debug" ${configure.args}] > -1} {
+    configure.args-delete     --enable-debug
+}
