@@ -1,9 +1,7 @@
 # -*- coding: utf-8; mode: tcl; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- vim:fenc=utf-8:ft=tcl:et:sw=4:ts=4:sts=4
-# muniversal-1.0.tcl
+# $Id: muniversal-1.0.tcl 107667 2013-07-04 04:53:46Z jeremyhu@macports.org $
 #
-# $Id: muniversal-1.0.tcl 91556 2012-04-05 02:17:53Z jeremyhu@macports.org $
-#
-# Copyright (c) 2009 The MacPorts Project,
+# Copyright (c) 2009-2013 The MacPorts Project,
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -18,7 +16,7 @@
 # 3. Neither the name of Apple Computer, Inc. nor the names of its
 #    contributors may be used to endorse or promote products derived from
 #    this software without specific prior written permission.
-# 
+#
 # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 # "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 # LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
@@ -35,9 +33,11 @@
 # User variables:
 #         merger_configure_env: associative array of configure.env variables
 #             merger_build_env: associative array of build.env variables
+#          merger_destroot_env: associative array of destroot.env variables
 #                  merger_host: associative array of host values
 #        merger_configure_args: associative array of configure.args
 #            merger_build_args: associative array of build.args
+#         merger_destroot_args: associative array of destroot.args
 #    merger_configure_compiler: associative array of configure.compiler
 #    merger_configure_cppflags: associative array of configure.cppflags
 #      merger_configure_cflags: associative array of configure.cflags
@@ -46,7 +46,6 @@
 #     merger_configure_ldflags: associative array of configure.ldflags
 #             merger_arch_flag: if no, -arch xxx will not be appended configure.???flags
 #         merger_arch_compiler: if no, -arch xxx will not be appended to compilers
-#          merger_destroot_env: associative array of destroot.env variables
 #             merger_dont_diff: list of file names for which diff will not work
 #     merger_must_run_binaries: if yes, build platform must be able to run binaries for supported architectures
 #            merger_no_3_archs: if yes, merger will not work correctly if there are three supported architectures
@@ -60,23 +59,7 @@ default merger_arch_compiler {no}
 
 proc muniversal_arch_flag_supported {args} {
     global configure.compiler
-    switch -exact ${configure.compiler} {
-        gcc-4.0 -
-        gcc-4.2 -
-        llvm-gcc-4.2 -
-        clang -
-        apple-gcc-4.0 -
-        apple-gcc-4.2 -
-        macports-clang-2.9 -
-        macports-clang-3.0 -
-        macports-clang-3.1 -
-        macports-clang {
-            return yes
-        }
-        default {
-            return no
-        }
-    }
+    return [regexp {^gcc-4|llvm|apple|clang} ${configure.compiler}]
 }
 
 proc muniversal_get_arch_flag {arch {fortran ""}} {
@@ -104,6 +87,34 @@ proc muniversal_get_arch_flag {arch {fortran ""}} {
     return ${archf}
 }
 
+# set up the merger-post-destroot hook
+
+proc merger_target_provides {ditem args} {
+    global targets
+    # register just the procedure, no pre-/post-
+    # User-code exceptions are caught and returned as a result of the target.
+    # Thus if the user code breaks, dependent targets will not execute.
+    foreach target $args {
+        set origproc [ditem_key $ditem procedure]
+        set ident [ditem_key $ditem name]
+        proc merger-post-$target {args} "
+            variable proc_index
+            set proc_index \[llength \[ditem_key $ditem post\]\]
+            ditem_append $ditem merger-post proc-merger-post-${ident}-${target}-\${proc_index}
+            proc proc-merger-post-${ident}-${target}-\${proc_index} {name} \"
+                if {\\\[catch userproc-merger-post-${ident}-${target}-\${proc_index} result\\\]} {
+                    return -code error \\\$result
+                } else {
+                    return 0
+                }
+            \"
+            makeuserproc userproc-merger-post-${ident}-${target}-\${proc_index} \$args
+        "
+    }
+}
+
+merger_target_provides ${org.macports.destroot} destroot
+
 variant universal {
     global universal_archs_to_use
 
@@ -181,7 +192,9 @@ variant universal {
         foreach arch ${universal_archs_to_use} {
             ui_info "$UI_PREFIX [format [msgcat::mc "Configuring %1\$s for architecture %2\$s"] $name ${arch}]"
 
-            copy ${worksrcpath} ${worksrcpath}-${arch}
+            if {![file exists ${worksrcpath}-${arch}]} {
+                copy ${worksrcpath} ${worksrcpath}-${arch}
+            }
 
             set archf [muniversal_get_arch_flag ${arch}]
             set archff [muniversal_get_arch_flag ${arch} "fortran"]
@@ -221,7 +234,7 @@ variant universal {
                 if { $merger_host($arch) != "" } {
                     set host  --host=$merger_host($arch)
                 }
-            } else {
+            } elseif {[file tail ${configure.cmd}] != "cmake"} {
                 # check if building for a word length we can't run
                 set bits_differ 0
                 if {(${arch}=="x86_64" || ${arch}=="ppc64") &&
@@ -353,7 +366,7 @@ variant universal {
     build {
         foreach arch ${universal_archs_to_use} {
             ui_info "$UI_PREFIX [format [msgcat::mc "Building %1\$s for architecture %2\$s"] $name ${arch}]"
-            
+
             if { [info exists merger_build_env(${arch})] } {
                 build.env-append  $merger_build_env(${arch})
             }
@@ -394,6 +407,9 @@ variant universal {
             if { [info exists merger_destroot_env(${arch})] } {
                 destroot.env-append  $merger_destroot_env(${arch})
             }
+            if { [info exists merger_destroot_args(${arch})] } {
+                destroot.args-append  $merger_destroot_args(${arch})
+            }
             set destroot_dir_save ${destroot.dir}
             if { [string match "${worksrcpath}/*" ${destroot.dir}] } {
                 # The destroot directory is inside the source directory, so put in the new source directory name.
@@ -409,6 +425,9 @@ variant universal {
             portdestroot::destroot_main
 
             destroot.dir  ${destroot_dir_save}
+            if { [info exists merger_destroot_args(${arch})] } {
+                destroot.args-delete $merger_destroot_args(${arch})
+            }
             if { [info exists merger_destroot_env(${arch})] } {
                 destroot.env-delete  $merger_destroot_env(${arch})
             }
@@ -416,6 +435,26 @@ variant universal {
         }
         delete ${destroot}
 
+        # execute merger-post-destroot, if it exists
+
+        set ditem ${org.macports.destroot}
+        set procedure [ditem_key $ditem merger-post]
+        if {$procedure != ""} {
+            set targetname [ditem_key $ditem name]
+            ui_debug "Executing org.macports.merger-post-destroot"
+            set result [catch { $procedure $targetname } errstr]
+            # Save variables in order to re-throw the same error code.
+            set errcode $::errorCode
+            set errinfo $::errorInfo
+            if {$result != 0} {
+                set portname $subport
+                ui_error "$targetname for port $portname returned: $errstr"
+                ui_debug "Error code: $errcode"
+                ui_debug "Backtrace: $errinfo"
+                return $result
+            }
+        }
+
         # Merge ${base1}/${prefixDir} and ${base2}/${prefixDir} into dir ${base}/${prefixDir}
         #        arch1, arch2: names to prepend to files if a diff merge of two files is forbidden by merger_dont_diff
         #    merger_dont_diff: list of files for which /usr/bin/diff ${diffFormat} will not merge correctly
@@ -428,14 +467,14 @@ variant universal {
             xinstall -d -m 0755 ${dir}
 
             foreach fl [glob -directory ${dir2} -tails -nocomplain *] {
-                if { ![file exists ${dir1}/${fl}] } {
+                if { ![muniversal_file_or_symlink_exists ${dir1}/${fl}] } {
                     # File only exists in ${dir1}
                     ui_debug "universal: merge: ${prefixDir}/${fl} only exists in ${base2}"
                     copy ${dir2}/${fl} ${dir}
                 }
             }
             foreach fl [glob -directory ${dir1} -tails -nocomplain *] {
-                if { ![file exists ${dir2}/${fl}] } {
+                if { ![muniversal_file_or_symlink_exists ${dir2}/${fl}] } {
                     # File only exists in ${dir2}
                     ui_debug "universal: merge: ${prefixDir}/${fl} only exists in ${base1}"
                     copy ${dir1}/${fl} ${dir}
@@ -535,9 +574,16 @@ variant universal {
                                         } else {
                                             # File created by diff is invalid
                                             delete ${dir}/${fl}
-                                            
+
                                             # nothing has worked so far.
                                             switch -glob ${fl} {
+                                                *.typelib {
+                                                    # Sometimes garbage ends up in ignored trailing bytes
+                                                    # https://trac.macports.org/ticket/39629
+                                                    # TODO: Compare the g-ir-generate output
+                                                    ui_debug "universal: merge: ${prefixDir}/${fl} differs in ${base1} and ${base2}; assume trivial difference"
+                                                    copy ${dir1}/${fl} ${dir}
+                                                }
                                                 *.jar {
                                                     # jar files can be different because of timestamp
                                                     ui_debug "universal: merge: ${prefixDir}/${fl} differs in ${base1} and ${base2}; assume timestamp difference"
@@ -652,3 +698,15 @@ variant universal {
         }
     }
 }
+
+# [muniversal_file_or_symlink_exists ${f}] tells you if ${f} exists. And unlike
+# [file exists ${f}], if used on a symlink, [muniversal_file_or_symlink_exists ${f}]
+# tells you about the symlink, not what it points to.
+proc muniversal_file_or_symlink_exists {f} {
+    # If [file type ${f}] throws an error, ${f} doesn't exist.
+    if {[catch {file type ${f}}]} {
+        return 0
+    }
+    # Otherwise, it does.
+    return 1
+}
