@@ -1,7 +1,7 @@
 # et:ts=4
-# python25-1.0.tcl
+# python32-1.0.tcl
 #
-# $Id: python25-1.0.tcl 78508 2011-05-10 08:33:40Z jmr@macports.org $
+# $Id: python32-1.0.tcl 105683 2013-05-01 22:21:55Z jmr@macports.org $
 #
 # Copyright (c) 2007 Markus W. Weissman <mww@macports.org>,
 # All rights reserved.
@@ -18,7 +18,7 @@
 # 3. Neither the name of Apple Computer, Inc. nor the names of its
 #    contributors may be used to endorse or promote products derived from
 #    this software without specific prior written permission.
-# 
+#
 # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 # "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 # LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
@@ -32,49 +32,36 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #
 
-set python.branch	2.5
-set python.bin	${prefix}/bin/python${python.branch}
-set python.lib	${prefix}/lib/libpython${python.branch}.dylib
-set python.libdir ${prefix}/lib/python${python.branch}
-set python.pkgd	${prefix}/lib/python${python.branch}/site-packages
-set python.include	${prefix}/include/python${python.branch}
+pre-fetch {
+    ui_error "The $name port is using the obsolete 'python32'\
+PortGroup. The maintainer should switch to the 'python' PortGroup."
+    error "obsolete PortGroup"
+}
+
+set python.branch	3.2
+set python.prefix	${frameworks_dir}/Python.framework/Versions/${python.branch}
+set python.bin		${python.prefix}/bin/python${python.branch}
+set python.lib		${python.prefix}/Python
+set python.libdir	${python.prefix}/lib/python${python.branch}
+set python.pkgd		${python.prefix}/lib/python${python.branch}/site-packages
+set python.include	${python.prefix}/include/python${python.branch}
 
 categories		python
 
 dist_subdir		python
 
-depends_lib		port:python25
-
 # we want the default universal variant added despite not using configure
-use_configure	no
+use_configure   no
 universal_variant yes
 
 build.cmd		${python.bin} setup.py --no-user-cfg
 build.target	build
 options python.add_archflags
 default python.add_archflags yes
-pre-build {
-    if {${python.add_archflags}} {
-        if {[variant_exists universal] && [variant_isset universal]} {
-            build.env-append CFLAGS="${configure.universal_cflags}" \
-                             OBJCFLAGS="${configure.universal_cflags}" \
-                             CXXFLAGS="${configure.universal_cxxflags}" \
-                             LDFLAGS="${configure.universal_ldflags}"
-        } else {
-            build.env-append CFLAGS="${configure.cc_archflags}" \
-                             OBJCFLAGS="${configure.objc_archflags}" \
-                             CXXFLAGS="${configure.cxx_archflags}" \
-                             FFLAGS="${configure.f77_archflags}" \
-                             F90FLAGS="${configure.f90_archflags}" \
-                             FCFLAGS="${configure.fc_archflags}" \
-                             LDFLAGS="${configure.ld_archflags}"
-        }
-    }
-}
 
 destroot.cmd	${python.bin} setup.py --no-user-cfg
-destroot.destdir	--prefix=${prefix} --root=${destroot}
+destroot.destdir	--prefix=${python.prefix} --root=${destroot}
 
-pre-destroot	{
-	xinstall -d -m 755 ${destroot}${prefix}/share/doc/${name}/examples
-}
+options         python.link_binaries python.link_binaries_suffix
+default python.link_binaries yes
+default python.link_binaries_suffix {-${python.branch}}
