@@ -17,9 +17,10 @@
 # Is the location of the SBT launcher JAR file.
 LAUNCHJAR="__SBT_LAUNCHER_PATH__"
 
-# Ensure enough heap space is created for SBT.
+# Ensure enough heap space is created for sbt.  These settings are the
+# default settings from Typesafe's sbt wrapper.
 if [ -z "$JAVA_OPTS" ]; then
-	JAVA_OPTS="-Xmx512M"
+    JAVA_OPTS="-XX:+CMSClassUnloadingEnabled -Xms1536m -Xmx1536m -XX:MaxPermSize=384m -XX:ReservedCodeCacheSize=192m -Dfile.encoding=UTF8"
 fi
 
 # Assume java is already in the shell path.
